@@ -35,7 +35,10 @@ __author__    = 'Tom Van Mele and many others (see CONTRIBUTORS.md)'
 __copyright__ = 'Copyright 2014-2018 - Block Research Group, ETH Zurich'
 __license__   = 'MIT License'
 __email__     = 'vanmelet@ethz.ch'
-__version__   = '0.3.2'
+__version__   = '0.3.4'
+
+
+PY3 = sys.version_info[0] == 3
 
 
 HERE = os.path.dirname(__file__)
@@ -137,6 +140,10 @@ def get(filename):
 
     """
     filename = filename.strip('/')
+
+    if filename.endswith('bunny.ply'):
+        return get_bunny()
+
     localpath = compas._os.absjoin(DATA, filename)
 
     if os.path.exists(localpath):
