@@ -12,7 +12,8 @@ except NameError:
 
 __all__ = [
     'FromToData',
-    'FromToJson'
+    'FromToJson',
+    'FromToPickle',
 ]
 
 
@@ -37,10 +38,6 @@ class FromToData(object):
         This constructor method is meant to be used in conjuction with the
         corresponding *to_data* method.
 
-        See Also
-        --------
-        * :meth:`to_data`
-
         """
         graph = cls()
         graph.data = data
@@ -59,10 +56,6 @@ class FromToData(object):
         This method produces the data that can be used in conjuction with the
         corresponding *from_data* class method.
 
-        See Also
-        --------
-        * :meth:`from_data`
-
         """
         return self.data
 
@@ -88,10 +81,6 @@ class FromToJson(object):
         This constructor method is meant to be used in conjuction with the
         corresponding *to_json* method.
 
-        See Also
-        --------
-        * :meth:`to_json`
-
         """
         with open(filepath, 'r') as fp:
             data = json.load(fp)
@@ -107,15 +96,49 @@ class FromToJson(object):
         filepath : str
             The path to the json file.
 
-        See Also
-        --------
-        * :meth:`from_json`
-
         """
         with open(filepath, 'w+') as fp:
             json.dump(self.data, fp)
 
 
+class FromToPickle(object):
+
+    @classmethod
+    def from_pickle(cls, filepath):
+        """Construct a datastructure from serialised data contained in a pickle file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the pickle file.
+
+        Returns
+        -------
+        object
+            An object of type ``cls``.
+
+        Note
+        ----
+        This constructor method is meant to be used in conjuction with the
+        corresponding *to_pickle* method.
+
+        """
+        o = cls()
+        o.load(filepath)
+        return o
+
+    def to_pickle(self, filepath):
+        """Serialised the structured data representing the data structure to a pickle file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the pickle file.
+
+        """
+        self.dump(filepath)
+
+
 # ==============================================================================
 # Main
 # ==============================================================================
