@@ -46,7 +46,7 @@ class VertexMappings(object):
         """
         return dict(enumerate(self.vertices()))
 
-    def key_gkey(self, precision='3f'):
+    def key_gkey(self, precision=None):
         """Returns a dictionary that maps vertex dictionary keys to the corresponding
         *geometric key* up to a certain precision.
 
@@ -70,7 +70,7 @@ class VertexMappings(object):
         xyz = self.vertex_coordinates
         return {key: gkey(xyz(key), precision) for key in self.vertices()}
 
-    def gkey_key(self, precision='3f'):
+    def gkey_key(self, precision=None):
         """Returns a dictionary that maps *geometric keys* of a certain precision
         to the keys of the corresponding vertices.
 
