@@ -27,7 +27,6 @@ from compas.geometry import normal_polygon
 from compas.geometry import area_polygon
 from compas.geometry import bestfit_plane
 from compas.geometry import flatness
-
 from compas.geometry import Polyhedron
 
 from compas.datastructures import Datastructure
@@ -48,6 +47,7 @@ from compas.datastructures._mixins import FaceFilter
 
 from compas.datastructures._mixins import FromToData
 from compas.datastructures._mixins import FromToJson
+from compas.datastructures._mixins import FromToPickle
 
 from compas.datastructures._mixins import VertexMappings
 from compas.datastructures._mixins import EdgeMappings
@@ -79,7 +79,8 @@ Mesh summary
 """
 
 
-class Mesh(FromToJson,
+class Mesh(FromToPickle,
+           FromToJson,
            FromToData,
            EdgeGeometry,
            FaceHelpers,
@@ -91,7 +92,6 @@ class Mesh(FromToJson,
            FaceMappings,
            EdgeMappings,
            VertexMappings,
-           VertexCoordinatesDescriptors,
            FaceAttributesManagement,
            VertexAttributesManagement,
            Datastructure):
@@ -100,27 +100,49 @@ class Mesh(FromToJson,
     Attributes
     ----------
     vertex : dict
-        The vertex dictionary.
-        With every key in the dictionary corresponds a dictionary of attributes.
+        A dictionary mapping vertex identifiers to vertex attributes.
     face : dict
-        The face dictionary.
-        With every key in the dictionary corresponds a dictionary of half-edges.
-    facedata : dict
-        A dictionary with face attributes.
-        For every face, there is a corresponding entry in this dict.
+        A dictionary mapping face identifiers to ordered face vertices.
     halfedge : dict
-        The half-edge dictionary.
-        Every key in the dictionary corresponds to a vertex of the mesh.
-        With every key corresponds a dictionary of neighbors pointing to face keys.
-    edge : dict
-        The edge dictionary.
-        Every key in the dictionary corresponds to a vertex.
-        With every key corresponds a dictionary of neighbors pointing to attribute dictionaries.
+        A dictionary mapping each vertex identifier to a dictionary that maps
+        vertex identifiers of the half-edges connected to the first vertex to the
+        corresponding faces.
+    facedata : dict
+        A dictionary mapping face identifiers to face attributes.
+    edgedata : dict
+        A dictionary mapping edge identifiers (pairs of vertex identifiers) to edge
+        attributes.
     attributes : dict
-        General mesh attributes.
+        A dictionary of general mesh attributes.
+
+    Examples
+    --------
+    .. plot::
+        :include-source:
+
+        import compas
+        from compas.datastructures import Mesh
+
+        mesh = Mesh.from_obj(compas.get('faces.obj'))
+
+        mesh.plot(
+            vertextext={key: key for key in network.vertices()},
+            vertexcolor={key: '#ff0000' for key in mesh.vertices_where({'vertex_degree': 2})}
+            vertexsize=0.2
+        )
 
     """
 
+    collapse_edge   = mesh_collapse_edge
+    split_face      = mesh_split_face
+    split_edge      = mesh_split_edge
+    unweld_vertices = mesh_unweld_vertices
+
+    collapse_edge_tri = trimesh_collapse_edge
+    split_edge_tri    = trimesh_split_edge
+    swap_edge_tri     = trimesh_swap_edge
+
+
     def __init__(self):
         super(Mesh, self).__init__()
         self._key_to_str = False
@@ -128,7 +150,7 @@ class Mesh(FromToJson,
         self._max_int_fkey = -1
 
         self.attributes = {
-            'name'         : None,
+            'name'         : 'Mesh',
             'color.vertex' : None,
             'color.edge'   : None,
             'color.face'   : None,
@@ -169,10 +191,6 @@ class Mesh(FromToJson,
     # special properties
     # --------------------------------------------------------------------------
 
-    @property
-    def adjacency(self):
-        return self.halfedge
-
     @property
     def name(self):
         """str : The name of the data structure.
@@ -186,6 +204,10 @@ class Mesh(FromToJson,
     def name(self, value):
         self.attributes['name'] = value
 
+    @property
+    def adjacency(self):
+        return self.halfedge
+
     @property
     def data(self):
         """dict: A data dict representing the mesh data structure for serialisation.
@@ -197,9 +219,9 @@ class Mesh(FromToJson,
         * 'dea'          => dict
         * 'dfa'          => dict
         * 'vertex'       => dict
-        * 'edge'         => dict
         * 'face'         => dict
         * 'facedata'     => dict
+        * 'edgedata'     => dict
         * 'max_int_key'  => int
         * 'max_int_fkey' => int
 
@@ -209,46 +231,34 @@ class Mesh(FromToJson,
         to ensure compatibility of all allowed key types with the JSON serialisation
         format, which only allows for dict keys that are strings.
 
-        See Also
-        --------
-        * :meth:`to_data`
-        * :meth:`to_json`
-        * :meth:`from_data`
-        * :meth:`from_json`
-
         """
         data = {'attributes'  : self.attributes,
                 'dva'         : self.default_vertex_attributes,
                 'dea'         : self.default_edge_attributes,
                 'dfa'         : self.default_face_attributes,
                 'vertex'      : {},
-                'edgedata'    : {},
                 'face'        : {},
                 'facedata'    : {},
+                'edgedata'    : {},
                 'max_int_key' : self._max_int_key,
                 'max_int_fkey': self._max_int_fkey, }
 
         for key in self.vertex:
-            rkey = repr(key)
-            data['vertex'][rkey] = self.vertex[key]
+            data['vertex'][repr(key)] = self.vertex[key]
 
         for fkey in self.face:
-            rfkey = repr(fkey)
-            data['face'][rfkey] = [repr(key) for key in self.face[fkey]]
+            data['face'][repr(fkey)] = [repr(key) for key in self.face[fkey]]
 
         for fkey in self.facedata:
-            rfkey = repr(fkey)
-            data['facedata'][rfkey] = self.facedata[fkey]
+            data['facedata'][repr(fkey)] = self.facedata[fkey]
 
         for uv in self.edgedata:
-            ruv = repr(uv)
-            data['edgedata'][ruv] = self.edgedata[uv]
+            data['edgedata'][repr(uv)] = self.edgedata[uv]
 
         return data
 
     @data.setter
     def data(self, data):
-        """"""
         attributes   = data.get('attributes') or {}
         dva          = data.get('dva') or {}
         dfa          = data.get('dfa') or {}
@@ -268,19 +278,15 @@ class Mesh(FromToJson,
         self.clear()
 
         for key, attr in iter(vertex.items()):
-            key = literal_eval(key)
-            self.add_vertex(key, attr_dict=attr)
+            self.add_vertex(literal_eval(key), attr_dict=attr)
 
         for fkey, vertices in iter(face.items()):
             attr = facedata.get(fkey) or {}
             vertices = [literal_eval(k) for k in vertices]
-            fkey = literal_eval(fkey)
-            self.add_face(vertices, fkey=fkey, attr_dict=attr)
+            self.add_face(vertices, fkey=literal_eval(fkey), attr_dict=attr)
 
         for uv, attr in iter(edgedata.items()):
-            attr = attr or {}
-            uv = literal_eval(uv)
-            self.edgedata[uv] = attr
+            self.edgedata[literal_eval(uv)] = attr or {}
 
         self._max_int_key = max_int_key
         self._max_int_fkey = max_int_fkey
@@ -290,15 +296,24 @@ class Mesh(FromToJson,
     # --------------------------------------------------------------------------
 
     def dump(self, filepath):
+        """Dump the data representing the mesh to a file using Python's built-in
+        object serialisation.
+
+        Parameters
+        ----------
+        filepath : str
+            Path to the dump file.
+
+        """
         data = {
             'attributes'  : self.attributes,
             'dva'         : self.default_vertex_attributes,
             'dea'         : self.default_edge_attributes,
             'dfa'         : self.default_face_attributes,
             'vertex'      : self.vertex,
-            'edgedata'    : self.edgedata,
             'face'        : self.face,
             'facedata'    : self.facedata,
+            'edgedata'    : self.edgedata,
             'max_int_key' : self._max_int_key,
             'max_int_fkey': self._max_int_fkey,
         }
@@ -306,21 +321,38 @@ class Mesh(FromToJson,
             pickle.dump(data, fo, protocol=pickle.HIGHEST_PROTOCOL)
 
     def dumps(self):
+        """Dump the data representing the mesh to a string using Python's built-in
+        object serialisation.
+
+        Returns
+        -------
+        str
+            The pickled string representation of the data.
+
+        """
         data = {
             'attributes'  : self.attributes,
             'dva'         : self.default_vertex_attributes,
             'dea'         : self.default_edge_attributes,
             'dfa'         : self.default_face_attributes,
             'vertex'      : self.vertex,
-            'edgedata'    : self.edgedata,
             'face'        : self.face,
             'facedata'    : self.facedata,
+            'edgedata'    : self.edgedata,
             'max_int_key' : self._max_int_key,
             'max_int_fkey': self._max_int_fkey,
         }
         return pickle.dumps(data, protocol=pickle.HIGHEST_PROTOCOL)
 
     def load(self, filepath):
+        """Load serialised mesh data from a pickle file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the pickle file.
+
+        """
         with open(filepath, 'rb') as fo:
             data = pickle.load(fo)
 
@@ -336,6 +368,14 @@ class Mesh(FromToJson,
         self._max_int_fkey = data['max_int_fkey']
 
     def loads(self, s):
+        """Load serialised mesh data from a pickle string.
+
+        Parameters
+        ----------
+        s : str
+            The pickled string.
+
+        """
         data = pickle.loads(s)
 
         self.attributes = data['attributes']
@@ -366,7 +406,7 @@ class Mesh(FromToJson,
 
         Returns
         -------
-        Mesh :
+        Mesh
             A mesh object.
 
         Note
@@ -382,9 +422,14 @@ class Mesh(FromToJson,
 
         Examples
         --------
-        >>> import compas
-        >>> from compas.datastructures import Mesh
-        >>> mesh = Mesh.from_obj(compas.get('faces.obj'))
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_obj(compas.get('faces.obj'))
+
+            mesh.plot()
 
         """
         obj = OBJ(filepath, precision)
@@ -419,9 +464,12 @@ class Mesh(FromToJson,
 
         Examples
         --------
-        >>> import compas
-        >>> from compas.datastructures import Mesh
-        >>> mesh = Mesh.from_obj(compas.get('bunny.ply'))
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_obj(compas.get('bunny.ply'))
 
         """
         ply = PLY(filepath)
@@ -432,6 +480,35 @@ class Mesh(FromToJson,
 
     @classmethod
     def from_stl(cls, filepath):
+        """Construct a mesh object from the data described in a STL file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the file.
+
+        Returns
+        -------
+        Mesh :
+            A mesh object.
+
+        Note
+        ----
+        There are a few sample files available for testing and debugging:
+
+        * cube_ascii.stl
+        * cube_binary.stl
+
+        Examples
+        --------
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_stl(compas.get('cube_ascii.stl'))
+
+        """
         stl = STL(filepath)
         vertices = stl.parser.vertices
         faces = stl.parser.faces
@@ -447,7 +524,7 @@ class Mesh(FromToJson,
         return leaves
 
     @classmethod
-    def from_lines(cls, lines, delete_boundary_face=False, precision='3f'):
+    def from_lines(cls, lines, delete_boundary_face=False, precision=None):
         """Construct a mesh object from a list of lines described by start and end point coordinates.
 
         Parameters
@@ -463,20 +540,22 @@ class Mesh(FromToJson,
 
         Returns
         -------
-        Mesh :
+        Mesh
             A mesh object.
 
-        See Also
-        --------
-        * :func:`compas.datastructures.network_find_faces`
-        * :func:`compas.datastructures.FaceNetwork`
-        * :meth:`from_vertices_and_faces`
-
         Examples
         --------
-        >>> import compas
-        >>> from compas.datastructures import Mesh
-        >>> mesh = Mesh.from_obj(compas.get('bunny.ply'))
+        .. code-block:: python
+
+            import json
+
+            import compas
+            from compas.datastructures import Mesh
+
+            with open(compas.get('lines.json'), 'r') as fo:
+                lines = json.load(fo)
+
+            mesh = Mesh.from_lines(lines)
 
         """
         from compas.topology import network_find_faces
@@ -487,7 +566,7 @@ class Mesh(FromToJson,
         mesh = cls()
 
         for key, attr in network.vertices(True):
-            mesh.add_vertex(key, x=attr['x'], y=attr['y'], z=0)
+            mesh.add_vertex(key, x=attr['x'], y=attr['y'], z=attr['z'])
 
         mesh.halfedge = network.halfedge
 
@@ -517,11 +596,15 @@ class Mesh(FromToJson,
 
         Examples
         --------
-        >>> import compas
-        >>> from compas.datastructures import Mesh
-        >>> vertices = [[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0]]
-        >>> faces = [[0, 1, 2]]
-        >>> mesh = Mesh.from_vertices_and_faces(vertices, faces)
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            vertices = [[0.0, 0.0, 0.0], [1.0, 0.0, 0.0], [1.0, 1.0, 0.0]]
+            faces = [[0, 1, 2]]
+
+            mesh = Mesh.from_vertices_and_faces(vertices, faces)
 
         """
         mesh = cls()
@@ -546,6 +629,15 @@ class Mesh(FromToJson,
         Mesh
             A mesh object.
 
+        Examples
+        --------
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_polyhedron(8)
+
         """
         p = Polyhedron.generate(f)
         return cls.from_vertices_and_faces(p.vertices, p.faces)
@@ -565,13 +657,19 @@ class Mesh(FromToJson,
         Mesh
             A mesh object.
 
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
         """
         from compas.topology import delaunay_from_points
         faces = delaunay_from_points(points, boundary=boundary, holes=holes)
         return cls.from_vertices_and_faces(points, faces)
 
     @classmethod
-    def from_polygons(cls, polygons, precision='3f'):
+    def from_polygons(cls, polygons, precision=None):
         """Construct a mesh from a series of polygons.
 
         Parameters
@@ -579,6 +677,8 @@ class Mesh(FromToJson,
         polygons : list
             A list of polygons, with each polygon defined as an ordered list of
             XYZ coordinates of its corners.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
 
         Returns
         -------
@@ -622,7 +722,9 @@ class Mesh(FromToJson,
 
         Examples
         --------
-        >>>
+        .. code-block:: python
+
+            pass
 
         """
         key_index = self.key_index()
@@ -650,7 +752,9 @@ class Mesh(FromToJson,
 
         Example
         -------
-        >>>
+        .. code-block:: python
+
+            pass
 
         """
         key_index = self.key_index()
@@ -813,22 +917,16 @@ class Mesh(FromToJson,
         If a key with an integer value is provided that is higher than the current
         highest integer key value, then the highest integer value is updated accordingly.
 
-        See Also
-        --------
-        * :meth:`add_face`
-        * :meth:`add_edge`
-
         Examples
         --------
-        >>> mesh = Mesh()
         >>> mesh.add_vertex()
-        '0'
+        0
         >>> mesh.add_vertex(x=0, y=0, z=0)
-        '1'
+        1
         >>> mesh.add_vertex(key=2)
-        '2'
+        2
         >>> mesh.add_vertex(key=0, x=1)
-        '0'
+        0
 
         """
         attr = self._compile_vattr(attr_dict, kwattr)
@@ -881,11 +979,6 @@ class Mesh(FromToJson,
         If a key with an integer value is provided that is higher than the current
         highest integer key value, then the highest integer value is updated accordingly.
 
-        See Also
-        --------
-        * :meth:`add_vertex`
-        * :meth:`add_edge`
-
         Examples
         --------
         >>>
@@ -1123,10 +1216,6 @@ class Mesh(FromToJson,
         """Count the number of faces in the mesh."""
         return len(list(self.faces()))
 
-    def number_of_halfedges(self):
-        """Count the number of halfedges in the mesh."""
-        return len(list(self.halfedges()))
-
     def is_valid(self):
         """Verify that the mesh is valid.
 
@@ -1316,9 +1405,11 @@ class Mesh(FromToJson,
             The next vertex as a (key, attr) tuple, if ``data`` is true.
 
         """
-        if data:
-            return iter(self.vertex.items())
-        return iter(self.vertex)
+        for key in self.vertex:
+            if data:
+                yield key, self.vertex[key]
+            else:
+                yield key
 
     def faces(self, data=False):
         """Iterate over the faces of the mesh.
@@ -1331,9 +1422,9 @@ class Mesh(FromToJson,
         Yields
         ------
         hashable
-            The next face identifier (*key*), if ``data`` is false.
+            The next face identifier (*key*), if ``data`` is ``False``.
         2-tuple
-            The next face as a (fkey, attr) tuple, if ``data`` is true.
+            The next face as a (fkey, attr) tuple, if ``data`` is ``True``.
 
         """
         for fkey in self.face:
@@ -1408,9 +1499,11 @@ class Mesh(FromToJson,
 
                 if (u, v) not in self.edgedata:
                     self.edgedata[u, v] = self.default_edge_attributes.copy()
+
                     if (v, u) in self.edgedata:
                         self.edgedata[u, v].update(self.edgedata[v, u])
                         del self.edgedata[v, u]
+
                     self.edgedata[v, u] = self.edgedata[u, v]
 
                 if data:
@@ -1535,7 +1628,6 @@ class Mesh(FromToJson,
             plotter.show()
 
         """
-
         temp = list(self.halfedge[key])
 
         if not ordered:
@@ -2053,8 +2145,6 @@ class Mesh(FromToJson,
         """
         for u, v in self.face_halfedges(f1):
             if self.halfedge[v][u] == f2:
-                # if v in self.edge[u]:
-                #     return u, v
                 return u, v
 
     # --------------------------------------------------------------------------
@@ -2117,7 +2207,7 @@ class Mesh(FromToJson,
             plotter.show()
 
         """
-        area = 0
+        area = 0.
 
         p0 = self.vertex_coordinates(key)
 
@@ -2175,7 +2265,19 @@ class Mesh(FromToJson,
 
     def vertex_normal(self, key):
         """Return the normal vector at the vertex as the weighted average of the
-        normals of the neighboring faces."""
+        normals of the neighboring faces.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            The components of the normal vector.
+
+        """
         vectors = [self.face_normal(fkey) for fkey in self.vertex_faces(key) if fkey is not None]
         return normalize_vector(centroid_points(vectors))
 
@@ -2276,9 +2378,6 @@ class Mesh(FromToJson,
         """
         return area_polygon(self.face_coordinates(fkey))
 
-    # def face_circle(self, fkey):
-    #     pass
-
     def face_flatness(self, fkey):
         """Compute the flatness of the mesh face.
 
@@ -2307,6 +2406,9 @@ class Mesh(FromToJson,
         face = range(len(self.face_vertices(fkey)))
         return flatness(vertices, [face])[0]
 
+    # def face_circle(self, fkey):
+    #     pass
+
     # def face_frame(self, fkey):
     #     pass
 
@@ -2339,6 +2441,7 @@ class Mesh(FromToJson,
 
         """
         vertices = set()
+
         for key, nbrs in iter(self.halfedge.items()):
             for nbr, face in iter(nbrs.items()):
                 if face is None:
@@ -2350,7 +2453,7 @@ class Mesh(FromToJson,
         if not ordered:
             return vertices
 
-        key = sorted([(key, self.vertex_coordinates(key)) for key in vertices_all], key=lambda x: (x[1][1], x[1][0]))[0][0]
+        key = sorted([(key, self.vertex_coordinates(key)) for key in vertices], key=lambda x: (x[1][1], x[1][0]))[0][0]
 
         vertices = []
         start = key
@@ -2452,8 +2555,8 @@ class Mesh(FromToJson,
             A dictionary compiled of remaining named arguments.
             Defaults to an empty dict.
 
-        Note
-        ----
+        Notes
+        -----
         Named arguments overwrite correpsonding key-value pairs in the attribute dictionary,
         if they exist.
 
@@ -2472,19 +2575,13 @@ class Mesh(FromToJson,
 
         Parameters
         ----------
-        key : tuple, list
+        key : tuple of hashable
             The identifier of the edge, in the form of a pair of vertex identifiers.
         name : str
             The name of the attribute.
         value : object
             The value of the attribute.
 
-        See Also
-        --------
-        * :meth:`set_edge_attributes`
-        * :meth:`set_edges_attribute`
-        * :meth:`set_edges_attributes`
-
         """
         u, v = key
         if (u, v) not in self.edgedata:
@@ -2500,24 +2597,12 @@ class Mesh(FromToJson,
 
         Parameters
         ----------
-        key : tuple, list
+        key : tuple of hashable
             The identifier of the edge, in the form of a pair of vertex identifiers.
-        attr_dict : dict (None)
-            A dictionary of attributes as name-value pairs.
-        kwattr : dict
-            A dictionary compiled of remaining named arguments.
-            Defaults to an empty dict.
-
-        Note
-        ----
-        Named arguments overwrite correpsonding name-value pairs in the attribute dictionary,
-        if they exist.
-
-        See Also
-        --------
-        * :meth:`set_edge_attribute`
-        * :meth:`set_edges_attribute`
-        * :meth:`set_edges_attributes`
+        names : list of str
+            The names of the attributes.
+        values : list of object
+            The values of the attributes.
 
         """
         for name, value in zip(names, values):
@@ -2532,17 +2617,11 @@ class Mesh(FromToJson,
             The name of the attribute.
         value : object
             The value of the attribute.
-        keys : iterable (None)
+        keys : list of hashable, optional
             A list of edge identifiers.
             Each edge identifier is a pair of vertex identifiers.
             Defaults to all edges.
 
-        See Also
-        --------
-        * :meth:`set_edge_attribute`
-        * :meth:`set_edge_attributes`
-        * :meth:`set_edges_attributes`
-
         """
         if not keys:
             keys = self.edges()
@@ -2554,26 +2633,14 @@ class Mesh(FromToJson,
 
         Parameters
         ----------
-        keys : iterable (None)
+        names : list of str
+            The names of the attributes.
+        values : list of object
+            The values of the attributes.
+        keys : list of hashable, optional
             A list of edge identifiers.
             Each edge identifier is a pair of vertex identifiers.
             Defaults to all edges.
-        attr_dict : dict (None)
-            A dictionary of attributes as name-value pairs.
-        kwattr : dict
-            A dictionary compiled of remaining named arguments.
-            Defaults to an empty dict.
-
-        Note
-        ----
-        Named arguments overwrite correpsonding name-value pairs in the attribute dictionary,
-        if they exist.
-
-        See Also
-        --------
-        * :meth:`set_edge_attribute`
-        * :meth:`set_edge_attributes`
-        * :meth:`set_edges_attribute`
 
         """
         for name, value in zip(names, values):
@@ -2584,7 +2651,7 @@ class Mesh(FromToJson,
 
         Parameters
         ----------
-        key : tuple, list
+        key : tuple of hashable
             The identifier of the edge, in the form of a pair of vertex identifiers.
         name : str
             The name of the attribute.
@@ -2597,29 +2664,27 @@ class Mesh(FromToJson,
             The value of the attribute,
             or the default value if the attribute does not exist.
 
-        See Also
-        --------
-        * :meth:`get_edge_attributes`
-        * :meth:`get_edges_attribute`
-        * :meth:`get_edges_attributes`
-
         """
-        if key not in self.edgedata:
-            self.set_edge_attributes(key, [], [])
-        return self.edgedata[key].get(name, value)
+        u, v = key
+        if (u, v) in self.edgedata:
+            return self.edgedata[u, v].get(name, value)
+        if (v, u) in self.edgedata:
+            return self.edgedata[v, u].get(name, value)
+        self.edgedata[u, v] = self.edgedata[v, u] = self.default_edge_attributes.copy()
+        return self.edgedata[u, v].get(name, value)
 
     def get_edge_attributes(self, key, names, values=None):
         """Get the value of a named attribute of one edge.
 
         Parameters
         ----------
-        key : tuple, list
+        key : tuple of hashable
             The identifier of the edge, in the form of a pair of vertex identifiers.
         names : list
             A list of attribute names.
-        values : list (None)
+        values : list, optional
             A list of default values.
-            Defaults to a list of ``None`` s.
+            Defaults to a list of ``None``.
 
         Returns
         -------
@@ -2628,12 +2693,6 @@ class Mesh(FromToJson,
             Every attribute that does not exist is replaced by the corresponding
             default value.
 
-        See Also
-        --------
-        * :meth:`get_edge_attribute`
-        * :meth:`get_edges_attribute`
-        * :meth:`get_edges_attributes`
-
         """
         if not values:
             values = [None] * len(names)
@@ -2659,12 +2718,6 @@ class Mesh(FromToJson,
         values : list
             A list of values of the named attribute of the specified edges.
 
-        See Also
-        --------
-        * :meth:`get_edge_attribute`
-        * :meth:`get_edge_attributes`
-        * :meth:`get_edges_attributes`
-
         """
         if not keys:
             keys = self.edges()
@@ -2678,10 +2731,10 @@ class Mesh(FromToJson,
         ----------
         names : list
             The names of the attributes.
-        values : list (None)
+        values : list, optional
             A list of default values.
-            Defaults to a list of ``None`` s.
-        keys : iterable (None)
+            Defaults to a list of ``None``.
+        keys : list of hashable, optional
             A list of edge identifiers.
             Each edge identifier is a pair of vertex identifiers.
             Defaults to all edges.
@@ -2693,29 +2746,87 @@ class Mesh(FromToJson,
             If an attribute does not exist for a specific edge, it is replaced
             by the default value.
 
-        See Also
-        --------
-        * :meth:`get_edge_attribute`
-        * :meth:`get_edge_attributes`
-        * :meth:`get_edges_attribute`
-
         """
         if not keys:
             keys = self.edges()
 
         return [self.get_edge_attributes(key, names, values) for key in keys]
 
+    # --------------------------------------------------------------------------
+    # visualisation
+    # --------------------------------------------------------------------------
 
-# move these to where they are needed
+    def plot(self,
+             vertexcolor=None,
+             edgecolor=None,
+             facecolor=None,
+             vertexsize=None,
+             edgewidth=None,
+             vertextext=None,
+             edgetext=None,
+             facetext=None):
+        """Plot a 2D representation of the mesh.
 
-Mesh.collapse_edge = mesh_collapse_edge.__get__(None, Mesh)
-Mesh.split_face = mesh_split_face.__get__(None, Mesh)
-Mesh.split_edge = mesh_split_edge.__get__(None, Mesh)
-Mesh.unweld_vertices = mesh_unweld_vertices.__get__(None, Mesh)
+        Parameters
+        ----------
+        vertexcolor : dict, optional
+            A dictionary mapping vertex identifiers to colors.
+        edgecolor : dict, optional
+            A dictionary mapping edge identifiers to colors.
+        facecolor : dict, optional
+            A dictionary mapping face identifiers to colors.
+        vertexsize : dict, optional
+            A dictionary mapping vertex identifiers to sizes.
+        edgewidth : dict, optional
+            A dictionary mapping edge identifiers to widths.
+        vertextext : dict, optional
+            A dictionary mappping vertex identifiers to labels.
+        edgetext : dict, optional
+            A dictionary mappping edge identifiers to labels.
+        facetext : dict, optional
+            A dictionary mappping face identifiers to labels.
 
-Mesh.collapse_edge_tri = trimesh_collapse_edge.__get__(None, Mesh)
-Mesh.split_edge_tri = trimesh_split_edge.__get__(None, Mesh)
-Mesh.swap_edge_tri = trimesh_swap_edge.__get__(None, Mesh)
+        Examples
+        --------
+        .. plot::
+            :include-source:
+
+            import compas
+            from compas.datastructures import Mesh
+
+            mesh = Mesh.from_obj(compas.get('faces.obj'))
+
+            mesh.plot()
+
+        """
+        from compas.plotters import MeshPlotter
+
+        plotter = MeshPlotter(self)
+        plotter.draw_vertices(
+            facecolor=vertexcolor,
+            radius=vertexsize,
+            text=vertextext
+        )
+        plotter.draw_edges(
+            color=edgecolor,
+            width=edgewidth,
+            text=edgetext
+        )
+        plotter.draw_faces(
+            facecolor=facecolor,
+            text=facetext
+        )
+        plotter.show()
+
+
+# Mesh.collapse_edge = mesh_collapse_edge.__get__(None, Mesh)
+# Mesh.split_face = mesh_split_face.__get__(None, Mesh)
+# Mesh.split_edge = mesh_split_edge.__get__(None, Mesh)
+# Mesh.unweld_vertices = mesh_unweld_vertices.__get__(None, Mesh)
+
+# Mesh.collapse_edge_tri = trimesh_collapse_edge.__get__(None, Mesh)
+# Mesh.split_edge_tri = trimesh_split_edge.__get__(None, Mesh)
+# Mesh.swap_edge_tri = trimesh_swap_edge.__get__(None, Mesh)
 
 
 # ==============================================================================
