@@ -3,11 +3,13 @@ from .insert import *
 from .split import *
 from .swap import *
 from .weld import *
+from .join import *
 
 from .collapse import __all__ as a
 from .insert import __all__ as c
 from .split import __all__ as d
 from .swap import __all__ as e
 from .weld import __all__ as f
+from .join import __all__ as g
 
-__all__ = a + c + d + e + f
+__all__ = a + c + d + e + f + g
