@@ -27,13 +27,7 @@ from compas.datastructures._mixins import FaceHelpers
 from compas.datastructures._mixins import FaceMappings
 
 
-__author__     = 'Tom Van Mele'
-__copyright__  = 'Copyright 2014, Block Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = '<vanmelet@ethz.ch>'
-
-
-__all__ = ['FaceNetwork', ]
+__all__ = ['FaceNetwork']
 
 
 class FaceNetwork(FaceHelpers,
