@@ -2,11 +2,13 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
+import pickle
+import pprint
+import json
+
 from copy import deepcopy
 from ast import literal_eval
 
-import compas
-
 from compas.files import OBJ
 
 from compas.utilities import geometric_key
@@ -89,16 +91,13 @@ class Network(FromToJson,
 
         import compas
         from compas.datastructures import Network
-        from compas.plotters import NetworkPlotter
 
         network = Network.from_obj(compas.get('lines.obj'))
 
-        plotter = NetworkPlotter(network)
-
-        plotter.draw_vertices(text={key: key for key in network.vertices()}, radius=0.2)
-        plotter.draw_edges()
-
-        plotter.show()
+        network.plot(
+            vertextext={key: key for key in network.vertices()},
+            vertexsize=0.2
+        )
 
     """
 
@@ -108,7 +107,7 @@ class Network(FromToJson,
         super(Network, self).__init__()
         self._key_to_str = False
         self._max_int_key = -1
-        self._key_to_str = False
+
         self.attributes = {
             'name'         : 'Network',
             'color.vertex' : None,
@@ -149,7 +148,7 @@ class Network(FromToJson,
 
     @property
     def name(self):
-        """:obj:`str` : The name of the data structure.
+        """str : The name of the data structure.
 
         Any value assigned to this property will be stored in the attribute dict
         of the data structure instance.
@@ -178,8 +177,7 @@ class Network(FromToJson,
                 'max_int_key' : self._max_int_key, }
 
         for key in self.vertex:
-            rkey = repr(key)
-            data['vertex'][rkey] = self.vertex[key]
+            data['vertex'][repr(key)] = self.vertex[key]
 
         for u in self.edge:
             ru = repr(u)
@@ -256,12 +254,128 @@ class Network(FromToJson,
 
         self._max_int_key = max_int_key
 
+    # --------------------------------------------------------------------------
+    # serialisation
+    # --------------------------------------------------------------------------
+
+    def dump(self, filepath):
+        """Dump the data representing the network to a file using Python's built-in
+        object serialisation.
+
+        Parameters
+        ----------
+        filepath : str
+            Path to the dump file.
+
+        """
+        data = {
+            'attributes'  : self.attributes,
+            'dva'         : self.default_vertex_attributes,
+            'dea'         : self.default_edge_attributes,
+            'vertex'      : self.vertex,
+            'edge'        : self.edge,
+            'halfedge'    : self.halfedge,
+            'max_int_key' : self._max_int_key,
+        }
+        with open(filepath, 'wb+') as fo:
+            pickle.dump(data, fo, protocol=pickle.HIGHEST_PROTOCOL)
+
+    def dumps(self):
+        """Dump the data representing the network to a string using Python's built-in
+        object serialisation.
+
+        Returns
+        -------
+        str
+            The pickled string representation of the data.
+
+        """
+        data = {
+            'attributes'  : self.attributes,
+            'dva'         : self.default_vertex_attributes,
+            'dea'         : self.default_edge_attributes,
+            'vertex'      : self.vertex,
+            'edge'        : self.edge,
+            'halfedge'    : self.halfedge,
+            'max_int_key' : self._max_int_key,
+        }
+        return pickle.dumps(data, protocol=pickle.HIGHEST_PROTOCOL)
+
+    def load(self, filepath):
+        """Load serialised network data from a pickle file.
+
+        Parameters
+        ----------
+        filepath : str
+            The path to the pickle file.
+
+        """
+        with open(filepath, 'rb') as fo:
+            data = pickle.load(fo)
+
+        self.attributes = data['attributes']
+        self.default_vertex_attributes = data['dva']
+        self.default_edge_attributes = data['dea']
+        self.vertex = data['vertex']
+        self.edge = data['edge']
+        self.halfedge = data['halfedge']
+        self._max_int_key = data['max_int_key']
+
+    def loads(self, s):
+        """Load serialised network data from a pickle string.
+
+        Parameters
+        ----------
+        s : str
+            The pickled string.
+
+        """
+        data = pickle.loads(s)
+
+        self.attributes = data['attributes']
+        self.default_vertex_attributes = data['dva']
+        self.default_edge_attributes = data['dea']
+        self.vertex = data['vertex']
+        self.edge = data['edge']
+        self.halfedge = data['halfedge']
+        self._max_int_key = data['max_int_key']
+
     # --------------------------------------------------------------------------
     # constructors
     # --------------------------------------------------------------------------
 
     @classmethod
-    def from_obj(cls, filepath, precision='3f'):
+    def from_obj(cls, filepath, precision=None):
+        """Construct a network from the data contained in an OBJ file.
+
+        Parameters
+        ----------
+        filepath : str
+            Path to the OBJ file.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
+
+        Returns
+        -------
+        Network
+            A network object.
+
+        Note
+        ----
+        There are a few sample files available for testing and debugging:
+
+        * lines.obj
+
+        Examples
+        --------
+        .. code-block:: python
+
+            import compas
+            from compas.datastructures import Network
+
+            network = Network.from_obj(compas.get('lines.obj'))
+
+        """
         network  = cls()
         obj      = OBJ(filepath, precision=precision)
         vertices = obj.parser.vertices
@@ -273,7 +387,36 @@ class Network(FromToJson,
         return network
 
     @classmethod
-    def from_lines(cls, lines, precision='3f'):
+    def from_lines(cls, lines, precision=None):
+        """Construct a network from a set of lines represented by their start and end point coordinates.
+
+        Parameters
+        ----------
+        lines : list
+            A list of pairs of point coordinates.
+        precision: str, optional
+            The precision of the geometric map that is used to connect the lines.
+
+        Returns
+        -------
+        Network
+            A network object.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            import json
+
+            import compas
+            from compas.datastructures import Network
+
+            with open(compas.get('lines.json'), 'r') as fo:
+                lines = json.load(fo)
+
+            network = Network.from_lines(lines)
+
+        """
         network = cls()
         edges   = []
         vertex  = {}
@@ -297,6 +440,26 @@ class Network(FromToJson,
 
     @classmethod
     def from_vertices_and_edges(cls, vertices, edges):
+        """Construct a network from vertices and edges.
+
+        Parameters
+        ----------
+        vertices : list of list of float
+            A list of vertex coordinates.
+        edges : list of tuple of int
+
+        Returns
+        -------
+        Network
+            A network object.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         network = cls()
         for x, y, z in vertices:
             network.add_vertex(x=x, y=y, z=z)
@@ -304,34 +467,88 @@ class Network(FromToJson,
             network.add_edge(u, v)
         return network
 
-    @classmethod
-    def from_grid(cls, xlim, ylim):
-        pass
-
     # --------------------------------------------------------------------------
     # converters
     # --------------------------------------------------------------------------
 
     def to_obj(self):
+        """Write the network to an OBJ file.
+
+        Parameters
+        ----------
+        filepath : str
+            Full path of the file.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         raise NotImplementedError
 
     def to_points(self, axes='xyz'):
+        """Return the coordinates of the network.
+
+        Parameters
+        ----------
+        axes : str, optional
+            The components of the point coordinates to return.
+            Default is to return XYZ components.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         return [self.vertex_coordinates(key, axes) for key in self.vertices()]
 
     def to_lines(self, axes='xyz'):
+        """Return the lines of the network as pairs of start and end point coordinates.
+
+        Parameters
+        ----------
+        axes : str, optional
+            The components of the point coordinates to return.
+            Default is to return XYZ components.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         return [self.edge_coordinates(u, v, axes=axes) for u, v in self.edges()]
 
     def to_vertices_and_edges(self):
+        """Return the vertices and edges of a network.
+
+        Returns
+        -------
+        tuple
+            A 2-tuple containing
+
+            * a list of vertices, represented by their XYZ coordinates, and
+            * a list of edges.
+
+            Each face is a list of indices referencing the list of vertex coordinates.
+
+        Example
+        -------
+        .. code-block:: python
+
+            pass
+
+        """
         key_index = dict((key, index) for index, key in enumerate(self.vertices()))
         vertices  = [self.vertex_coordinates(key) for key in self.vertices()]
         edges     = [(key_index[u], key_index[v]) for u, v in self.edges()]
         return vertices, edges
 
-    def to_points_and_lines(self):
-        points = [self.vertex_coordinates(key) for key in self.vertices()]
-        lines = [self.edge_coordinates(u, v) for u, v in self.edges()]
-        return points, lines
-
     # --------------------------------------------------------------------------
     # helpers
     # move to mixin
@@ -353,15 +570,22 @@ class Network(FromToJson,
         return key
 
     def copy(self):
+        """Make an independent copy of the network object.
+
+        Returns
+        -------
+        Network
+            A separate, but identical network object.
+
+        """
         cls = type(self)
         return cls.from_data(deepcopy(self.data))
 
     def clear(self):
+        """Clear all the network data."""
         del self.vertex
         del self.edge
         del self.halfedge
-        del self.face
-        del self.facedata
         self.vertex   = {}
         self.edge     = {}
         self.halfedge = {}
@@ -369,15 +593,18 @@ class Network(FromToJson,
         self._max_int_fkey = -1
 
     def clear_vertexdict(self):
+        """Clear only the vertices."""
         del self.vertex
         self.vertex = {}
         self._max_int_key = -1
 
     def clear_edgedict(self):
+        """Clear only the edges."""
         del self.edge
         self.edge = {}
 
     def clear_halfedgedict(self):
+        """Clear only the half-edges."""
         del self.halfedge
         self.halfedge = {}
 
@@ -388,32 +615,40 @@ class Network(FromToJson,
     def add_vertex(self, key=None, attr_dict=None, **kwattr):
         """Add a vertex and specify its attributes (optional).
 
-        Notes:
-            If no key is provided for the vertex, one is generated
-            automatically. An automatically generated key increments the highest
-            key in use by 1::
+        Parameters
+        ----------
+        key : hashable, optional
+            An identifier for the vertex.
+            Defaults to ``None``, in which case an identifier of type ``int`` is automatically generated.
+        attr_dict : dict, optional
+            Vertex attributes, defaults to ``None``.
+        kwattr
+            Other named vertex attributes, defaults to an empty dict.
 
-                key = int(sorted(self.vertex.keys())[-1]) + 1
+        Returns
+        -------
+        str
+            The key of the vertex.
 
-        Parameters:
-            key (int): An identifier for the vertex. Defaults to None. The key
-                is converted to a string before it is used.
-            attr_dict (dict): Vertex attributes, defaults to ``None``.
-            **attr: Other named vertex attributes, defaults to an empty :obj:`dict`.
+        Notes
+        -----
+        If no key is provided for the vertex, one is generated
+        automatically. An automatically generated key increments the highest
+        key in use by 1::
 
-        Returns:
-            str: The key of the vertex.
+            key = int(sorted(self.vertex.keys())[-1]) + 1
+
+        Examples
+        --------
+        >>> network.add_vertex()
+        0
+        >>> network.add_vertex(x=0, y=0, z=0)
+        1
+        >>> network.add_vertex(key=2)
+        2
+        >>> network.add_vertex(key=0, x=1)
+        0
 
-        Examples:
-            >>> network = Network()
-            >>> network.add_vertex()
-            '0'
-            >>> network.add_vertex(x=0, y=0, z=0)
-            '1'
-            >>> network.add_vertex(key=2)
-            '2'
-            >>> network.add_vertex(key=0, x=1)
-            '0'
         """
         attr = deepcopy(self.default_vertex_attributes)
         if not attr_dict:
@@ -433,7 +668,31 @@ class Network(FromToJson,
         return key
 
     def add_edge(self, u, v, attr_dict=None, **kwattr):
-        """Add an edge and specify its attributes (optional)."""
+        """Add an edge and specify its attributes.
+
+        Parameters
+        ----------
+        u : hashable
+            The identifier of the first vertex of the edge.
+        v : hashable
+            The identifier of the second vertex of the edge.
+        attr_dict : dict, optional
+            A dictionary of edge attributes.
+        kwattr
+            Other edge attributes as additional keyword arguments.
+
+        Returns
+        -------
+        tuple
+            The identifiers of the edge vertices.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         attr = deepcopy(self.default_edge_attributes)
         if not attr_dict:
             attr_dict = {}
@@ -461,6 +720,20 @@ class Network(FromToJson,
     # --------------------------------------------------------------------------
 
     def delete_vertex(self, key):
+        """Delete a vertex from the network.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         for nbr in self.vertex_neighbors(key):
             del self.halfedge[key][nbr]
             del self.halfedge[nbr][key]
@@ -473,6 +746,22 @@ class Network(FromToJson,
         del self.edge[key]
 
     def delete_edge(self, u, v):
+        """Delete an edge from the network.
+
+        Parameters
+        ----------
+        u : hashable
+            The identifier of the first vertex.
+        v : hashable
+            The identifier of the second vertex.
+
+        Examples
+        --------
+        .. code-block:: python
+
+            pass
+
+        """
         del self.halfedge[u][v]
         del self.halfedge[v][u]
         if u in self.edge and v in self.edge[u]:
@@ -485,44 +774,67 @@ class Network(FromToJson,
     # --------------------------------------------------------------------------
 
     def number_of_vertices(self):
+        """Compute the number of vertices of the network.
+
+        Returns
+        -------
+        int
+            the number of vertices.
+
+        """
         return len(list(self.vertices()))
 
     def number_of_edges(self):
+        """Compute the number of edges of the network.
+
+        Returns
+        -------
+        int
+            the number of edges.
+
+        """
         return len(list(self.edges()))
 
-    def number_of_halfedges(self):
-        return len(list(self.halfedges()))
-
-    # def is_connected(self):
-    #     """Return True if for every two vertices a path exists connecting them."""
-    #     if not self.vertex:
-    #         return False
-
-    #     root = self.get_any_vertex()
-    #     nodes = breadth_first_traverse(self.halfedge, root)
-
-    #     return len(nodes) == self.number_of_vertices()
-
     # --------------------------------------------------------------------------
     # accessors
     # --------------------------------------------------------------------------
 
     def vertices(self, data=False):
-        """Return an iterator for the vertices and their attributes (optional).
+        """Iterate over the vertices of the network.
 
-        Parameters:
-            data (bool): Return key, data pairs, defaults to False.
+        Parameters
+        ----------
+        data : bool, optional
+            If ``True``, yield both the identifier and the attributes.
+
+        Yields
+        ------
+        hashable
+            The next vertex identifier (*key*), if ``data`` is ``False``.
+        2-tuple
+            The next vertex as a (key, attr) tuple, if ``data`` is ``True``.
 
-        Returns:
-            iter: An iterator of vertex keys, if data is False.
-            iter: An iterator of key, data pairs, if data is True.
         """
         if data:
             return iter(self.vertex.items())
         return iter(self.vertex)
 
     def edges(self, data=False):
-        """Return an iterator for the edges and their attributes (optional)."""
+        """Iterate over the edges of the network.
+
+        Parameters
+        ----------
+        data : bool, optional
+            If ``True``, yield both the identifier and the attributes.
+
+        Yields
+        ------
+        2-tuple
+            The next edge identifier (u, v), if ``data`` is ``False``.
+        3-tuple
+            The next vertex as a (u, v, attr) tuple, if ``data`` is ``True``.
+
+        """
         for u, nbrs in iter(self.edge.items()):
             for v, attr in iter(nbrs.items()):
                 if data:
@@ -534,9 +846,9 @@ class Network(FromToJson,
     # additional accessors
     # --------------------------------------------------------------------------
 
-    def indexed_edges(self):
-        k_i = self.key_index()
-        return [(k_i[u], k_i[v]) for u, v in self.edges()]
+    # def indexed_edges(self):
+    #     k_i = self.key_index()
+    #     return [(k_i[u], k_i[v]) for u, v in self.edges()]
 
     # --------------------------------------------------------------------------
     # default attributes
@@ -563,26 +875,101 @@ class Network(FromToJson,
     # --------------------------------------------------------------------------
 
     def has_vertex(self, key):
+        """Verify if a specific vertex is present in the network.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        bool
+            True or False.
+
+        """
         return key in self.vertex
 
     def is_vertex_leaf(self, key):
+        """Verify if a vertex is a leaf.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        bool
+            True or False.
+
+        Notes
+        -----
+        A vertex is a *leaf* if it has only one neighbor.
+
+        """
         return self.vertex_degree(key) == 1
 
     def leaves(self):
+        """Return all leaves of the network.
+
+        Returns
+        -------
+        list
+            A list of vertex identifiers.
+
+        """
         return [key for key in self.vertices() if self.is_vertex_leaf(key)]
 
-    def is_vertex_orphan(self, key):
-        return not self.vertex_degree(key) > 0
-
     def is_vertex_connected(self, key):
+        """Verify if a specific vertex is connected.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        bool
+            True or False.
+
+        """
         return self.vertex_degree(key) > 0
 
     def vertex_neighbors(self, key):
-        """Return the neighbors of a vertex."""
+        """Return the neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            A list of vertex identifiers.
+
+        """
         return list(self.halfedge[key])
 
     def vertex_neighborhood(self, key, ring=1):
-        """Return the vertices in the neighborhood of a vertex."""
+        """Return the vertices in the neighborhood of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+        ring : int, optional
+            The size of the neighborhood.
+            Default is ``1``.
+
+        Returns
+        -------
+        list
+            A list of vertex identifiers.
+
+        """
         nbrs = set(self.vertex_neighbors(key))
 
         i = 1
@@ -598,30 +985,102 @@ class Network(FromToJson,
 
             i += 1
 
-        return nbrs
+        return list(nbrs)
 
     def vertex_neighbors_out(self, key):
-        """Return the outgoing neighbors of a vertex."""
+        """Return the outgoing neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            A list of vertex identifiers.
+
+        """
         return list(self.edge[key])
 
     def vertex_neighbors_in(self, key):
-        """Return the incoming neighbors of a vertex."""
+        """Return the incoming neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            A list of vertex identifiers.
+
+        """
         return list(set(self.halfedge[key]) - set(self.edge[key]))
 
     def vertex_degree(self, key):
-        """Return the number of neighbors of a vertex."""
+        """Return the number of neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        int
+            The number of neighbors of the vertex.
+
+        """
         return len(self.vertex_neighbors(key))
 
     def vertex_degree_out(self, key):
-        """Return the number of outgoing neighbors of a vertex."""
+        """Return the number of outgoing neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        int
+            The number of outgoing neighbors of the vertex.
+
+        """
         return len(self.vertex_neighbors_out(key))
 
     def vertex_degree_in(self, key):
-        """Return the numer of incoming neighbors of a vertex."""
+        """Return the numer of incoming neighbors of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        int
+            The number of incoming neighbors of the vertex.
+
+        """
         return len(self.vertex_neighbors_in(key))
 
     def vertex_connected_edges(self, key):
-        """Return the edges connected to a vertex."""
+        """Return the edges connected to a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            The edges connected to the vertex.
+
+        """
         edges = []
         for nbr in self.vertex_neighbors(key):
             if nbr in self.edge[key]:
@@ -635,11 +1094,44 @@ class Network(FromToJson,
     # --------------------------------------------------------------------------
 
     def has_edge(self, u, v, directed=True):
+        """Verify if the network contains a specific edge.
+
+        Parameters
+        ----------
+        u : hashable
+            The identifier of the first vertex of the edge.
+        v : hashable
+            The identifier of the secondt vertex of the edge.
+        directed : bool, optional
+            Take into accoun the direction of the edge.
+            Default is ``True``.
+
+        Returns
+        -------
+        bool
+            True if the edge is present, False otherwise.
+
+        """
         if directed:
             return u in self.edge and v in self.edge[u]
         return (u in self.edge and v in self.edge[u]) or (v in self.edge and u in self.edge[v])
 
     def edge_connected_edges(self, u, v):
+        """Return the edges connected to an edge.
+
+        Parameters
+        ----------
+        u : hashable
+            The identifier of the first vertex of the edge.
+        v : hashable
+            The identifier of the secondt vertex of the edge.
+
+        Returns
+        -------
+        list
+            A list of connected edges.
+
+        """
         edges = []
         for nbr in self.vertex_neighbors(u):
             if nbr in self.edge[u]:
@@ -658,16 +1150,56 @@ class Network(FromToJson,
     # --------------------------------------------------------------------------
 
     def vertex_coordinates(self, key, axes='xyz'):
-        """Return the coordinates of a vertex."""
+        """Return the coordinates of a vertex.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+        axes : str, optional
+            The components of the vertex coordinates to return.
+            Default is ``'xyz'``.
+
+        Returns
+        -------
+        list
+            The coordniates of the vertex.
+
+        """
         return [self.vertex[key][axis] for axis in axes]
 
     def vertex_laplacian(self, key):
-        """Return the vector from the vertex to the centroid of its 1-ring neighborhood."""
+        """Return the vector from the vertex to the centroid of its 1-ring neighborhood.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            The laplacian vector.
+
+        """
         c = centroid_points([self.vertex_coordinates(nbr) for nbr in self.neighbors(key)])
         p = self.vertex_coordinates(key)
         return subtract_vectors(c, p)
 
     def vertex_neighborhood_centroid(self, key):
+        """Compute the centroid of the neighboring vertices.
+
+        Parameters
+        ----------
+        key : hashable
+            The identifier of the vertex.
+
+        Returns
+        -------
+        list
+            The coordinates of the centroid.
+
+        """
         return centroid_points([self.vertex_coordinates(nbr) for nbr in self.neighbors(key)])
 
     # --------------------------------------------------------------------------
@@ -688,6 +1220,62 @@ class Network(FromToJson,
 
     # inherited from EdgeAttributesMixin
 
+    # --------------------------------------------------------------------------
+    # visualisation
+    # --------------------------------------------------------------------------
+
+    def plot(self,
+             vertexcolor=None,
+             edgecolor=None,
+             vertexsize=None,
+             edgewidth=None,
+             vertextext=None,
+             edgetext=None):
+        """Plot a 2D representation of the network.
+
+        Parameters
+        ----------
+        vertexcolor : dict, optional
+            A dictionary mapping vertex identifiers to colors.
+        edgecolor : dict, optional
+            A dictionary mapping edge identifiers to colors.
+        vertexsize : dict, optional
+            A dictionary mapping vertex identifiers to sizes.
+        edgewidth : dict, optional
+            A dictionary mapping edge identifiers to widths.
+        vertextext : dict, optional
+            A dictionary mappping vertex identifiers to labels.
+        edgetext : dict, optional
+            A dictionary mappping edge identifiers to labels.
+
+        Examples
+        --------
+        .. plot::
+            :include-source:
+
+            import compas
+            from compas.datastructures import Network
+
+            network = Network.from_obj(compas.get('lines.obj'))
+
+            network.plot()
+
+        """
+        from compas.plotters import NetworkPlotter
+
+        plotter = NetworkPlotter(self)
+        plotter.draw_vertices(
+            facecolor=vertexcolor,
+            radius=vertexsize,
+            text=vertextext
+        )
+        plotter.draw_edges(
+            color=edgecolor,
+            width=edgewidth,
+            text=edgetext
+        )
+        plotter.show()
+
 
 # ==============================================================================
 # Main
@@ -695,6 +1283,8 @@ class Network(FromToJson,
 
 if __name__ == '__main__':
 
+    import compas
+
     from compas.plotters import NetworkPlotter
 
     network = Network.from_obj(compas.get('lines.obj'))
