@@ -7,12 +7,6 @@ from compas.geometry import center_of_mass_polygon
 from compas.geometry import area_polygon
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2016 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
 __all__ = [
     'smooth_centroid',
     'smooth_centerofmass',
