@@ -10,6 +10,7 @@ from math import pi
 from compas.geometry.basic import length_vector
 from compas.geometry.basic import cross_vectors
 from compas.geometry.basic import subtract_vectors
+from compas.geometry.angles import angle_vectors
 
 from compas.geometry.transformations import transform_vectors
 
@@ -252,6 +253,22 @@ class Vector(object):
         """
         return Vector(self.x * n, self.y * n, self.z * n)
 
+    def __truediv__(self, n):
+        """Return a ``Vector`` that is the scaled version of this ``Vector``.
+
+        Parameters
+        ----------
+        n : float
+            The scaling factor.
+
+        Returns
+        -------
+        Vector
+            The resulting new ``Vector``.
+
+        """
+        return Vector(self.x / n, self.y / n, self.z / n)
+
     def __pow__(self, n):
         """Create a ``Vector`` from the components of the current ``Vector`` raised
         to the given power.
@@ -285,6 +302,7 @@ class Vector(object):
         self.x += other[0]
         self.y += other[1]
         self.z += other[2]
+        return self
 
     def __isub__(self, other):
         """Subtract the components of the other vector from this ``Vector``.
@@ -298,6 +316,7 @@ class Vector(object):
         self.x -= other[0]
         self.y -= other[1]
         self.z -= other[2]
+        return self
 
     def __imul__(self, n):
         """Multiply the components of this ``Vector`` by the given factor.
@@ -311,6 +330,21 @@ class Vector(object):
         self.x *= n
         self.y *= n
         self.z *= n
+        return self
+
+    def __itruediv__(self, n):
+        """Divide the components of this ``Vector`` by the given factor.
+
+        Parameters
+        ----------
+        n : float
+            The multiplication factor.
+
+        """
+        self.x /= n
+        self.y /= n
+        self.z /= n
+        return self
 
     def __ipow__(self, n):
         """Raise the components of this ``Vector`` to the given power.
@@ -324,6 +358,7 @@ class Vector(object):
         self.x **= n
         self.y **= n
         self.z **= n
+        return self
 
     # ==========================================================================
     # static methods
@@ -526,6 +561,9 @@ if __name__ == '__main__':
     u = Vector(0.0, 0.0, 1.0)
     v = Vector(1.0, 0.0, 0.0)
 
+    print(u.angle(v))
+    print(3.14159 / 2)
+
     w = Vector.from_start_end(u, v)
 
     print(w)
