@@ -3,15 +3,7 @@ from __future__ import division
 from __future__ import print_function
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2017 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
-__all__ = [
-    'mma'
-]
+__all__ = ['mma']
 
 
 def mma():
