@@ -5,13 +5,6 @@ compas.plotters
 
 .. currentmodule:: compas.plotters
 
-This package wraps the Matplotlib plotting library to create a
-two-dimensional visualization toolbox geared towards the datastructures, dynamic
-visualization of algorithm progress, and simple user interaction. The plotting
-package is built around `Matplotlib`_.
-
-.. _Matplotlib: https://matplotlib.org/
-
 
 Classes
 =======
