@@ -6,12 +6,6 @@ import time
 import datetime
 
 
-__author__    = 'Tom Van Mele'
-__copyright__ = 'Copyright 2016, Block Research Group - ETH Zurich'
-__license__   = 'MIT license'
-__email__     = 'vanmelet@ethz.ch'
-
-
 __all__ = [
     'timestamp',
 ]
