@@ -5,12 +5,6 @@ compas.viewers
 
 .. currentmodule:: compas.viewers
 
-This package wraps `PyOpenGL`_ and `PySide`_ to provide three-dimensional
-viewers with basic visualization and user interaction capabilities.
-
-.. _PyOpenGL: http://pyopengl.sourceforge.net
-.. _PySide: http://pyside.github.io/docs/pyside/index.html
-
 
 Classes
 =======
