@@ -7,12 +7,6 @@ from OpenGL.GLUT import *
 from OpenGL.GLU import *
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2016 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
 __all__ = [
     'make_vertex_buffer',
     'make_index_buffer'
