@@ -4,6 +4,7 @@ from __future__ import division
 
 import ast
 
+import compas
 import compas_rhino
 
 try:
@@ -11,20 +12,10 @@ try:
     from Rhino.Geometry import Point3d
 
 except ImportError:
-    import sys
-    if 'ironpython' in sys.version.lower():
-        raise
+    compas.raise_if_ironpython()
 
 
-__author__    = ['Tom Van Mele', ]
-__copyright__ = 'Copyright 2016 - Block Research Group, ETH Zurich'
-__license__   = 'MIT License'
-__email__     = 'vanmelet@ethz.ch'
-
-
-__all__ = [
-    'VertexModifier',
-]
+__all__ = ['VertexModifier']
 
 
 class VertexModifier(object):
