@@ -2,6 +2,8 @@ from __future__ import print_function
 
 from functools import wraps
 
+import compas
+
 from compas.geometry import center_of_mass_polygon
 
 from compas_rhino.utilities import create_layers_from_path
@@ -46,9 +48,7 @@ try:
     TOL = sc.doc.ModelAbsoluteTolerance
 
 except ImportError:
-    import sys
-    if 'ironpython' in sys.version.lower():
-        raise
+    compas.raise_if_ironpython()
 
 else:
     try:
@@ -57,12 +57,6 @@ else:
         find_layer_by_fullpath = None
 
 
-__author__     = ['Tom Van Mele', ]
-__copyright__  = 'Copyright 2014, BLOCK Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
 __all__ = [
     'xdraw_labels',
     'xdraw_points',
