@@ -1,5 +1,11 @@
+from __future__ import print_function
+from __future__ import absolute_import
+from __future__ import division
+
 from ast import literal_eval
 
+import compas
+
 try:
     import System
     import Rhino
@@ -9,9 +15,7 @@ try:
     find_object = sc.doc.Objects.Find
 
 except ImportError:
-    import sys
-    if 'ironpython' in sys.version.lower():
-        raise
+    compas.raise_if_ironpython()
 
 else:
     try:
@@ -20,12 +24,6 @@ else:
         purge_object = None
 
 
-__author__     = ['Tom Van Mele', ]
-__copyright__  = 'Copyright 2014, BLOCK Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
 # get_point_coordinates => get_coordinates_points
 # get_line_coordinates => get_coordinates_lines
 # get_polyline_coordinates => get_coordinates_polylines
@@ -634,5 +632,4 @@ def get_mesh_edge_vertex_indices(guid):
 # ==============================================================================
 
 if __name__ == '__main__':
-
     pass
